@@ -28,6 +28,9 @@ new lambda.Function(this, 'MyLambda', {
 });
 ```
 '''
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
